summaryrefslogtreecommitdiff
path: root/MdePkg/Library/BasePeCoffLib
diff options
context:
space:
mode:
Diffstat (limited to 'MdePkg/Library/BasePeCoffLib')
-rw-r--r--MdePkg/Library/BasePeCoffLib/BasePeCoff.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/MdePkg/Library/BasePeCoffLib/BasePeCoff.c b/MdePkg/Library/BasePeCoffLib/BasePeCoff.c
index e3a7b5387b..fcdf0c6647 100644
--- a/MdePkg/Library/BasePeCoffLib/BasePeCoff.c
+++ b/MdePkg/Library/BasePeCoffLib/BasePeCoff.c
@@ -254,10 +254,11 @@ PeCoffLoaderGetImageInfo (
ImageContext->DestinationAddress = 0;
//
// Initialize the codeview pointer.
//
- ImageContext->CodeView = NULL;
- ImageContext->PdbPointer = NULL;
+ ImageContext->DebugDirectoryEntryRva = 0;
+ ImageContext->CodeView = NULL;
+ ImageContext->PdbPointer = NULL;
//
// Three cases with regards to relocations:
@@ -254,10 +254,11 @@ PeCoffLoaderGetImageInfo (
ImageContext->DestinationAddress = 0;
//
- // Initialize the codeview pointer.
+ // Initialize the debug codeview pointer.
//